% This is the main run file for estimating the copulas models
% A1, A5, B1, B5, T1, and T5 in the validation section 2.3.2 of 
% Loaiza-Maya, R., Smith, M. S., and Maneesoonthorn, W. (2017).
%%%-- Constants set in function <set_constants>
%--->  var                Set to 1 for JPY/USD, 2 for  AUD/USD and 3 for EUR/USD
%--->  lag                Markov order of the copula model
%--->  y:                 Exchange rate returns of the variable selected by <var>
%--->  J:                 Constant indicating the number of MCMC steps
%--->  B:                 Constant indicating the number of MCMC burning steps
%--->  family:            Family of copulas used in the components of c_mix
%--->  [LB,UB]:           Lower and upper bounds for copula parameters.
%--->  lambda:            Prior parameter for the exponential prior used for nu whenever t copulas are used.
clear
tic
[var,p,y,J,B,LB,UB,family,lambda] = set_constants();                                          % Setting data, Markov order and copula family.
log_gam_prior = set_priors(lambda,family);                                                     % Setting priors.
[AC,S,u,dist,Gamma,step,log_post,G,numpar] = set_initial_states(y,B,J,family,log_gam_prior,p);   % Setting initial states and storage matrices.
for outer = 1:2
    for i =  1:S(outer)
         %----------------  Printing state  ---------------------------------------------------%
        if mod(i,100)==0
            disp(['|---' ' Stage ' num2str(outer) ', Iter ' num2str(i) ', E.t = ' num2str(round(toc*100)/100) ' sec ---|'] );
            disp('gamma_1 = ');
            disp(num2str(round(1000*Gamma(1:numpar))/1000));
            tic
        end
        for k = 1:p
        %----------------  sampling copula parameters  ----------------------------------%
            [Gamma,AC,log_post] = gen_gamma(Gamma,step,log_gam_prior,LB,UB,u,family,AC,k,log_post) ;
        %----------------  step update  ---------------------------------------------------%
            [step,AC] = step_update(100,AC,step,[0.15,0.30],i,1.5,k,numpar);
        end
        %--------------------- Collection
        if (outer ==2)
            G(i,:) = Gamma;
        end
    end
end
%-- Posterior mean estimates of the parameters
G_hat = mean(G);
%-- Prediction of the 5% and 95% VaR
hor = 1;                                                                   % Horizon
n = 1000;                                                                  % Draws to simulated from the predictive density
parfor t = p+1:length(u)
u_pred = c_DV_predict(n,reshape(G_hat,numpar,p),hor,family,u(1:t));
y_pred(t,:) = icdf(dist,u_pred);
end
idx = (p+1):(length(u)-1);
VaR = quantile(y_pred,[0.05 0.95],2);
plot(y(idx+1))
hold on
plot(VaR(idx,:))
hold off
legend('Observed Data','VaR(5%)','VaR(95%)')