% Prediction from heteroskedastic D-Vine copulas as in section 2.3 of 
% Loaiza-Maya et al. (2017).
%%%Inputs
% n:        Number of draws to simulate from the predictive density.
% Param:    Copula parameters. Should be a numparXp matrix. Column i contains the parameters from the pair-copula that captures i lagged serial dependence.
% hor:      Predictive horizon 
% family:   Copula family of the D-Vine components.
% u:        Vector with the copula data from a time series. u = (u_1,...,u_T)'
%%%Output
% u_pred:   This is a horXn matrix. Row j contains n draws from the predictive density of u_{T+j}
function u_pred = c_DV_predict(n,Param,hor,family,u)
numpar = size(Param,1);
p = size(Param,2);
[h1,~] = hfunctions_u(u(end-p:end),Param(:)',family,numpar);
H1 = repmat(h1(end,:),n,1);                                                % h1(end,:) = (u_{t-p|t-1},u_{t-p|t+1},...,u_{t-1})
H2 = zeros(n,p);
u_pred = zeros(hor,n);
for t = 1:hor
    for k =1:p
        try
            utGiventmpm1pk =  H2(:,k-1);                                   %u_t|{t-p-1+k}
        catch
            utGiventmpm1pk =  rand(n,1);                                   %u_t|{t-p-1+k}
        end
        H2(:,k) = invh(utGiventmpm1pk,H1(:,k),Param(:,p-k+1),family);      %u_t = hinv_1 o hinv_2 o --- o hinv_p(w|u_{t-p|t-1})
    end
    u_pred(t,:) = H2(:,end)';
    for k = 1:p                                                            % Update H1 for next prediction
        if k==p
            H1(:,k) = H2(:,end);    
        elseif k<p
            H1(:,k) = h_func(H1(:,k+1),H2(:,k+1),family,Param(:,p-k));    
        end
    end
    if mod(t,100)==0
        t
    end
end