%%%-- Description
% This functions draws from the conditional poterior of the pair-copula (PC)
% parameters using Metropolis Hastings.
%%%-- Input
% lag:           Indicates the lag of serial depedence captured by the PC.
% gamma_old:     Vector containing old values of the D-Vine parameters.
% step:          Current step size (stdev) of the PC parameters proposal.
% LB and UB:     Lower and Upper bound of the PC parameters.
% family:        PC family.
% log_gam_prior: A function that evaluates the log of the prior distribution.
% u:             Copula data (pseudo sample).
% AC:            Count of accepted draws in previous steps.
% log_post:      Logarithm of the posterior distribution evaluated at gamma_old.
%%%-- Output
% gamma_new:     Vector containing new drawn values of the PC parameters.
% AC:            Count of accepted draws after this step.
% log_post:      Logarithm of the posterior distribution evaluated at gamma_new.
function [gamma_new,AC,log_post] = gen_gamma(gamma_old,step,log_gam_prior,LB,UB,u,family,AC,lag,log_post)
% Number of parameters for each pair-copula
switch family
    case 'gumbel_mix'
        numpar = 5;
    case 't_mix'
        numpar = 5;
    case 't'
        numpar = 2;
end
idx = (numpar*(lag-1)+1):(numpar*lag);                                             % Indicates position of the parameters of pair-copula <lag> in the vector
gamma_prop = gamma_old;
[gamma_prop(idx),R] = q_gamma(gamma_old(idx),step(idx),LB(idx),UB(idx),1:numpar);  % Drawing form the proposal distribution
log_pri_new = log_gam_prior(gamma_prop);                     
likeli_new = lnc_DVine(gamma_prop,u,family,numpar);
alpha = min(exp(likeli_new+log_pri_new-log_post+R),1);
r = rand();
if alpha<r
    gamma_new = gamma_old;
else
    gamma_new = gamma_prop;
    log_post = likeli_new+log_pri_new;
end
AC(lag) = AC(lag)+ (alpha>=r);          