%%%-- Constants set in function <set_constants>
%--->  var:               Set to 1 for USD/JPY, 2 for  USD/AUD and 3 for USD/EUR
%--->  p:                 Markov order of the copula model
%--->  y:                 Exchange rate returns of the variable selected by <var>
%--->  J:                 Constant indicating the number of MCMC steps
%--->  B:                 Constant indicating the number of MCMC burning steps
%--->  family:            Family of copulas used in the components of c_mix
%--->  [LB,UB]:           Lower and upper bounds for copula parameters.
%--->  lambda:            Prior parameter for the exponential prior used for nu whenever t copulas are used.
%%%--- To estimate the copula models in section 2.3.2 set the <p> and <family> as:
% Copula A1: p = 1, family = 't_mix'
% Copula A5: p = 5, family = 't_mix'
% Copula B1: p = 1, family = 'gumbel_mix'
% Copula B5: p = 5, family = 'gumbel_mix'
% Copula T1: p = 1, family = 't'
% Copula T5: p = 5, family = 't'
function [var,p,y,J,B,LB,UB,family,lambda] = set_constants()
var = 2;                                                                   % Set to 1 for USD/JPY, 2 for  USD/AUD and 3 for USD/EUR
p = 1;                                                                     % Markov order of the D-Vine copula
family = 't_mix';
Data = csvread('Data.csv');
y = diff(Data(:,var));
J = 50000;
B = 10000;
switch family                                                              % Setting initial parameter values according to copula family
    case 't_mix'
        LB = [0 0.03 0 0.03 0];
        UB = [0.99 40  0.99 40 0.99];
    case 'gumbel_mix'
        LB = [0 0 0 0 0];
        UB = [0.99 0.99  0.99 0.99 0.99];
    case 't'
        LB = [-0.99 0.03];
        UB = [0.99 40];
end
LB = repmat(LB,1,p);
UB = repmat(UB,1,p);
lambda = 10;                          %-- lambda: is the expectation of the exponential distribution used as a prior for nu.