%%% Description
% This function modifies the RWMH step to achieve acceptance rate between 
% the limits set in <limits>
%%% Input
%checkat:  Constant indicating how often is MH step adapted
%i:        MCMC iteration index.
%AC:       Count of draws accepted over the last <mod(i-1,checkat)+1> iterations
%step:     Current length of step
%AR_lims:  Desired acceptance rate limits; [min max]
%c:        Constant indicating step modification if the acceptance rate is outside AR_lims; c>1.
%lag:      Order of serial dependence captured by the pair-copula.
%numpar:   Number of pair-copula parameters.
%%% Output
%step:     Adapted step.
%AC:       Set to zero when <checkat = mod(i-1,checkat)+1>.
function [step,AC] = step_update(checkat,AC,step,AR_lims,i,c,lag,numpar)
stepL = step((numpar*(lag-1)+1):(numpar*lag));
if mod(i,checkat)==0
    ratio = AC(lag)/checkat;
    step((numpar*(lag-1)+1):(numpar*lag)) = stepL*c*(ratio>=AR_lims(2))+ stepL*(1/c)*(ratio<=AR_lims(1))+stepL*(ratio>AR_lims(1))*(ratio<AR_lims(2));
    AC(lag) = 0;
end
